pub fn scan(plan: &Plan) -> (Vec<FileStat>, ScanMetrics)Expand description
Reconcile candidates from the effective scopes. The provider whitelist is applied before a path is returned to the indexer.
pub fn scan(plan: &Plan) -> (Vec<FileStat>, ScanMetrics)Reconcile candidates from the effective scopes. The provider whitelist is applied before a path is returned to the indexer.