pub struct Resolved {
pub text: String,
pub from_file: bool,
}Expand description
A payload value with its origin, after scheme resolution.
Fields
text: StringThe resolved value text.
from_file: boolTrue when the value was read from a file: source — such payloads
are verbatim: never promoted, matched literally by default.