read_steer

Function read_steer 

pub fn read_steer(
    file_path: &str,
    offset: Option<i64>,
    limit: Option<i64>,
) -> Option<Steer>
Steer a harness Read call to ct view — unless the path is something ct view (a line reader) cannot render (an image, PDF, or notebook), where Read is the right tool and the call is left alone (None).