pub fn run_background_poll()Expand description
The entry point for ct --update-check-run: perform one conditional GET
against the sparse index and update the cached state. Silent and infallible.
pub fn run_background_poll()The entry point for ct --update-check-run: perform one conditional GET
against the sparse index and update the cached state. Silent and infallible.